@@ -20,7 +20,7 @@ GenOO::RegionCollection - Role for a collection of GenOO::Region objects
 # Let the code begin...
 
 package GenOO::RegionCollection;
-$GenOO::RegionCollection::VERSION = '1.4.9';
+$GenOO::RegionCollection::VERSION = '1.5.0';
 use Moose::Role;
 use namespace::autoclean;
 use GenOO::RegionCollection::Factory;
@@ -38,8 +38,8 @@ requires qw (
 	rnames_for_all_strands
 	is_empty
 	is_not_empty
-	foreach_overlapping_record_do
-	records_overlapping_region
+	foreach_contained_record_do
+	records_contained_in_region
 );
 
 #######################################################################
